@@ -1,11 +1,15 @@
 from .pyutils.version import get_version
 from .relay import (
+    BaseGlobalIDType,
     ClientIDMutation,
     Connection,
     ConnectionField,
+    DefaultGlobalIDType,
     GlobalID,
     Node,
     PageInfo,
+    SimpleGlobalIDType,
+    UUIDGlobalIDType,
     is_node,
 )
 from .types import (
@@ -42,7 +46,7 @@ from .types import (
 from .utils.module_loading import lazy_import
 from .utils.resolve_only_args import resolve_only_args
 
-VERSION = (3, 1, 1, "final", 0)
+VERSION = (3, 2, 1, "final", 0)
 
 
 __version__ = get_version(VERSION)
@@ -52,6 +56,7 @@ __all__ = [
     "Argument",
     "Base64",
     "BigInt",
+    "BaseGlobalIDType",
     "Boolean",
     "ClientIDMutation",
     "Connection",
@@ -60,6 +65,7 @@ __all__ = [
     "Date",
     "DateTime",
     "Decimal",
+    "DefaultGlobalIDType",
     "Dynamic",
     "Enum",
     "Field",
@@ -80,10 +86,12 @@ __all__ = [
     "ResolveInfo",
     "Scalar",
     "Schema",
+    "SimpleGlobalIDType",
     "String",
     "Time",
-    "UUID",
     "Union",
+    "UUID",
+    "UUIDGlobalIDType",
     "is_node",
     "lazy_import",
     "resolve_only_args",
